<?php
/**
 * 用户登录日志记录，要求typecho至少在1.2版本
 * 
 * @package userlog
 * @author 泽泽社长
 * @version 1.6.0
 *
 * @update: 2021.1.7
 * @link https://blog.zezeshe.com/archives/userlog-typecho-plugin.html
 */
class userlog_Plugin implements Typecho_Plugin_Interface
{
    /**
     * 激活插件方法,如果激活失败,直接抛出异常 @dependence 18.10.2-*
     * 
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
     
    public static $panel  = 'userlog/Action.php';
    
    public static function activate()
    {
$info = self::installDb();//启动插件时建立表
Typecho_Plugin::factory('Widget_User')->loginSucceed = array('userlog_Plugin', 'loginlog');//用户登录成功接口
Typecho_Plugin::factory('Widget_User')->simpleLoginSucceed = array('userlog_Plugin', 'simpleloginlog');//插件登录成功接口一般为社交登录，typecho开发板或者正式版1.2版本可用
Helper::addPanel(1, self::$panel, '用户登录日志', '用户登录日志', 'editor');
return _t($info);//表建立成功与否提示
    }

    /**
     * 禁用插件方法,如果禁用失败,直接抛出异常
     * 
     * @static
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function deactivate(){
         Helper::removePanel(1, self::$panel); 
    }
    
    /**
     * 获取插件配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form 配置面板
     * @return void
     */
    public static function config(Typecho_Widget_Helper_Form $form)
    {


    }

    /**
     * 个人用户的配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form
     * @return void
     */
    public static function personalConfig(Typecho_Widget_Helper_Form $form){}

    public static function loginlog($user,$name,$pwd,$remember)
    {
$db = Typecho_Db::get();
date_default_timezone_set("Asia/Chongqing"); // PRC为中华人名共和国
$time = time();//当前时间时间戳
$insert = $db->insert('table.userlog')
    ->rows(array('uid' => $user->uid,'name' => $name,'screenName' =>$user->screenName, 'time' => $time, 'status'=>'0'));//预定插入数据
$insertId = $db->query($insert);//插入数据到数据库
    }
    
    public static function simpleloginlog($obj,$user)
    {
$db = Typecho_Db::get();
date_default_timezone_set("Asia/Chongqing"); // PRC为中华人名共和国
$time = time();//当前时间时间戳
$insert = $db->insert('table.userlog')
    ->rows(array('uid' => $user['uid'],'name' => $user['name'],'screenName' =>$user['screenName'], 'time' => $time, 'status'=>'1'));//预定插入数据
$insertId = $db->query($insert);//插入数据到数据库
    }
    
    /**
	 * 安装数据库
	 */
	public static function installDb(){
		$db = Typecho_Db::get();
		$type = explode('_', $db->getAdapterName());
		$type = array_pop($type);
		$prefix = $db->getPrefix();
		$scripts = file_get_contents(Helper::options()->pluginUrl.'/userlog/'.$type.'.sql');
		$scripts = str_replace('typecho_', $prefix, $scripts);
		$scripts = str_replace('%charset%', 'utf8', $scripts);
		$scripts = explode(';', $scripts);
		try {
			foreach ($scripts as $script) {
				$script = trim($script);
				if ($script) {
					$db->query($script, Typecho_Db::WRITE);
				}
			}
			return '建立Typecho用户日志数据表，插件启用成功';
		} catch (Typecho_Db_Exception $e) {
			$code = $e->getCode();
			if(('Mysql' == $type && 1050 == $code) ||
					('SQLite' == $type && ('HY000' == $code || 1 == $code))) {
				try {
					$script = 'SELECT `uid` from `' . $prefix . 'connect`';
					$db->query($script, Typecho_Db::READ);
					return '检测到Typecho用户日志数据表，Typecho用户日志插件启用成功';					
				} catch (Typecho_Db_Exception $e) {
					$code = $e->getCode();
					if(('Mysql' == $type && 1054 == $code) ||
							('SQLite' == $type && ('HY000' == $code || 1 == $code))) {
						return self::updateDb($db, $type, $prefix);
					}
					throw new Typecho_Plugin_Exception('数据表检测失败，Typecho用户日志插件启用失败。错误号：'.$code);
				}
			} else {
				throw new Typecho_Plugin_Exception('数据表建立失败，Typecho用户日志插件启用失败。错误号：'.$code);
			}
		}
	}
}
